@@ -5,7 +5,6 @@ __init__ is going to export all the code written in this module.
 Makes it super easy for people to import smooch and call whatever they need.
 """
 import os
-import logging
 
 if os.getenv("SMOOCH_KEY_ID") is None or os.getenv("SMOOCH_SECRET") is None:
     print("Smooch must have access to the SMOOCH_KEY_ID and SMOOCH_SECRET to operate."
@@ -13,9 +12,6 @@ if os.getenv("SMOOCH_KEY_ID") is None or os.getenv("SMOOCH_SECRET") is None:
           "\n'export SMOOCH_SECRET=\"your_smooch_secret\"'")
     exit(1)
 
-logging.basicConfig(level=logging.DEBUG,
-                    format='%(asctime)s - %(levelname)s - %(filename)s - %(lineno)d  - %(message)s')
-
 from .conversations import (
     send_message, get_conversation
 )
@@ -23,10 +19,10 @@ from .conversations import (
 from .payments import request_payment
 
 from .webhooks import (
-    get_webhook, delete_all_webhooks,
+    get_webhook, delete_all_webhooks, create_webhook,
     list_webhooks, ensure_webhook_exist, delete_webhook, update_webhook
 )
 
 from .app_users import (
-    pre_create_user, get_user, update_user, init_user, track_event
+    pre_create_user, get_user, update_user, init_user
 )
